@@ -1,16 +1,31 @@
-# - Copyright 2020 InterDigital Communications, Inc.
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# Copyright (c) 2021-2022, InterDigital Communications, Inc
+# All rights reserved.
+
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted (subject to the limitations in the disclaimer
+# below) provided that the following conditions are met:
+
+# * Redistributions of source code must retain the above copyright notice,
+#   this list of conditions and the following disclaimer.
+# * Redistributions in binary form must reproduce the above copyright notice,
+#   this list of conditions and the following disclaimer in the documentation
+#   and/or other materials provided with the distribution.
+# * Neither the name of InterDigital Communications, Inc nor the names of its
+#   contributors may be used to endorse or promote products derived from this
+#   software without specific prior written permission.
+
+# NO EXPRESS OR IMPLIED LICENSES TO ANY PARTY'S PATENT RIGHTS ARE GRANTED BY
+# THIS LICENSE. THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
+# CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT
+# NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
+# PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
+# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
+# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
+# WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
+# OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
+# ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 """
 Simple plotting utility to display Rate-Distortion curves (RD) comparison
 between codecs.
@@ -37,25 +52,30 @@ def parse_json_file(filepath, metric):
             print(f'Error reading file "{filepath}"')
             raise err
 
-    if "results" not in data or "bpp" not in data["results"]:
-        raise ValueError(f'Invalid file "{filepath}"')
+    if "results" in data:
+        results = data["results"]
+    else:
+        results = data
 
-    if metric not in data["results"]:
+    if metric not in results:
         raise ValueError(
             f'Error: metric "{metric}" not available.'
-            f' Available metrics: {", ".join(data["results"].keys())}'
+            f' Available metrics: {", ".join(results.keys())}'
         )
 
-    if metric == "ms-ssim":
-        # Convert to db
-        values = np.array(data["results"][metric])
-        data["results"][metric] = -10 * np.log10(1 - values)
+    try:
+        if metric == "ms-ssim":
+            # Convert to db
+            values = np.array(results[metric])
+            results[metric] = -10 * np.log10(1 - values)
 
-    return {
-        "name": data.get("name", name),
-        "xs": data["results"]["bpp"],
-        "ys": data["results"][metric],
-    }
+        return {
+            "name": data.get("name", name),
+            "xs": results["bpp"],
+            "ys": results[metric],
+        }
+    except KeyError:
+        raise ValueError(f'Invalid file "{filepath}"')
 
 
 def matplotlib_plt(
